==> open-xchange-core_7.10.5.orig.tar.bz2: open-xchange-core-7.10.5/com.openexchange.global/src/com/openexchange/exception/OXExceptionCode.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.exception;

/**
 * {@link OXExceptionCode} - Provides identifying information for an {@link OXException}.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public interface OXExceptionCode extends Code, OXExceptionConstants {

    /**
     * Checks if attributes of specified {@link OXException} instance or the ones from any of its causes (recursive check) matches this
     * code's ones.
     *
     * @param e The exception to check
     * @return <code>true</code> if specified {@link OXException}'s attributes matches this code's ones; otherwise <code>false</code>
     */
    boolean equals(OXException e);

    /**
     * Gets the {@link OXException}'s initial category.
     *
     * @return The initial category.
     */
    Category getCategory();

    /**
     * Gets the message either for display or for logging purpose.
     *
     * @return The message
     */
    String getMessage();
}

==> open-xchange-core_7.10.6.orig.tar.bz2: open-xchange-core-7.10.6/com.openexchange.global/src/com/openexchange/exception/OXExceptionCode.java <==
/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.exception;

/**
 * {@link OXExceptionCode} - Provides identifying information for an {@link OXException}.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public interface OXExceptionCode extends Code, OXExceptionConstants {

    /**
     * Checks if attributes of specified {@link OXException} instance or the ones from any of its causes (recursive check) matches this
     * code's ones.
     *
     * @param e The exception to check
     * @return <code>true</code> if specified {@link OXException}'s attributes matches this code's ones; otherwise <code>false</code>
     */
    boolean equals(OXException e);

    /**
     * Gets the {@link OXException}'s initial category.
     *
     * @return The initial category.
     */
    Category getCategory();

    /**
     * Gets the message for either display or for logging purpose.
     *
     * @return The message
     */
    String getMessage();
}
